pub struct FixedSlotCapacityQuery {
pub capacity_types: Option<Vec<CapacityType>>,
pub slot_duration: Option<f32>,
pub start_date_time: String,
pub end_date_time: String,
}Expand description
FixedSlotCapacityQuery : Request schema for the getFixedSlotCapacity operation. This schema is used to define the time range, capacity types and slot duration which are being queried.
Fields
capacity_types: Option<Vec<CapacityType>>An array of capacity types which are being requested. Default value is [SCHEDULED_CAPACITY].
slot_duration: Option<f32>Size in which slots are being requested. This value should be a multiple of 5 and fall in the range: 5 <= slotDuration <= 360.
start_date_time: StringStart date time from which the capacity slots are being requested in ISO 8601 format.
end_date_time: StringEnd date time up to which the capacity slots are being requested in ISO 8601 format.
Implementations
sourceimpl FixedSlotCapacityQuery
impl FixedSlotCapacityQuery
sourcepub fn new(
start_date_time: String,
end_date_time: String
) -> FixedSlotCapacityQuery
pub fn new(
start_date_time: String,
end_date_time: String
) -> FixedSlotCapacityQuery
Request schema for the getFixedSlotCapacity operation. This schema is used to define the time range, capacity types and slot duration which are being queried.